==> mcu_plus_sdk_am261x_11_00_00_29_docs_only.tar.xz: mcu_plus_sdk_am261x_11_00_00_29_docs_only/docs/api_guide_am261x/group__DRV__OSPI__NOR__FLASH__API__MODULE.js <==
var group__DRV__OSPI__NOR__FLASH__API__MODULE =
[
    [ "OSPI_norFlashInit1s1s1s", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gadb0a14dcb309721542c6a56b12c4b773", null ],
    [ "OSPI_norFlashSetCmds", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga21478324d9a1bf773a7899b6328d6396", null ],
    [ "OSPI_norFlashReadId", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga62272fc7c39a26461d2fd507fdb00262", null ],
    [ "OSPI_norFlashWrite", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gad13a8cac4ae2c44098b4efb9bef7c3b9", null ],
    [ "OSPI_norFlashRead", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga447cebdb3a900f51d0e8530e438be42b", null ],
    [ "OSPI_norFlashReadSfdp", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gaec858fb13f69ddc7c12ad43c9f5d9a33", null ],
    [ "OSPI_norFlashErase", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga198e9b4d58875e23c205a1352784655f", null ],
    [ "OSPI_configResetPin", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga91a633ee97b2714998956532f79c3af0", null ],
    [ "OSPI_configBaudrate", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gaa2e6caaca51234f8438bf183a9668371", null ],
    [ "OSPI_readBaudRateDivFromReg", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gacd2e47532e230e9483fd237c4483d00f", null ],
    [ "OSPI_getBaudRateDivFromObj", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga9245450f7a454c847b625d16d1ca9de4", null ],
    [ "OSPI_setResetPinStatus", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga571cf9598daae7049416eb502b493e88", null ]
];

==> mcu_plus_sdk_am261x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am261x_11_01_00_19_docs_only/docs/api_guide_am261x/group__DRV__OSPI__NOR__FLASH__API__MODULE.js <==
var group__DRV__OSPI__NOR__FLASH__API__MODULE =
[
    [ "OSPI_norFlashInit1s1s1s", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gadb0a14dcb309721542c6a56b12c4b773", null ],
    [ "OSPI_norFlashSetCmds", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga21478324d9a1bf773a7899b6328d6396", null ],
    [ "OSPI_norFlashReadId", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga62272fc7c39a26461d2fd507fdb00262", null ],
    [ "OSPI_norFlashWrite", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gad13a8cac4ae2c44098b4efb9bef7c3b9", null ],
    [ "OSPI_norFlashRead", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga447cebdb3a900f51d0e8530e438be42b", null ],
    [ "OSPI_norFlashReadSfdp", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gaec858fb13f69ddc7c12ad43c9f5d9a33", null ],
    [ "OSPI_norFlashErase", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga198e9b4d58875e23c205a1352784655f", null ],
    [ "OSPI_configResetPin", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga91a633ee97b2714998956532f79c3af0", null ],
    [ "OSPI_configBaudrate", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gaa2e6caaca51234f8438bf183a9668371", null ],
    [ "OSPI_readBaudRateDivFromReg", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gacd2e47532e230e9483fd237c4483d00f", null ],
    [ "OSPI_getBaudRateDivFromObj", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga9245450f7a454c847b625d16d1ca9de4", null ],
    [ "OSPI_setResetPinStatus", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga571cf9598daae7049416eb502b493e88", null ],
    [ "OSPI_phyValidateTuningPoint", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gacdf02bfd0923a1131c2550dbff2a274b", null ],
    [ "OSPI_isValidateOtpEnable", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga0ee9c708db4f78a7dd88a0eb68dadca0", null ],
    [ "OSPI_setFrequency", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga12d03e24e5378860702fcd3a3ee72d12", null ],
    [ "OSPI_setDelays", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#ga55a8848488b2dddfe65b1cafa330e9d1", null ],
    [ "OSPI_setBaudRateDiv", "group__DRV__OSPI__NOR__FLASH__API__MODULE.html#gacb120f1d20c835efd02acaef7dd4e545", null ]
];
